:tocdepth: 4

Welcome to the piecash documentation!
=====================================

:Release: |version|
:Date: |today|
:Authors: sdementen
:Project page: https://github.com/sdementen/piecash

.. toctree::
   :maxdepth: 1

   news.rst

Contents:

.. toctree::
   :maxdepth: 2

   doc/doc.rst
   tutorial/index_existing.rst
   tutorial/index_new.rst
   tutorial/examples.rst
   doc/comparison.rst

For developers
==============

The complete api documentation (apidoc) :

.. toctree::
   :maxdepth: 1

   api/piecash.rst

An overall view on the core objects in GnuCash:

.. toctree::
   :maxdepth: 1

   object_model.rst

A list of resources used for the project:

.. toctree::
   :maxdepth: 1

   doc/resources.rst

The todo list:

- write more tests
- review non core objects (:py:mod:`~piecash.budget`, :py:mod:`~piecash.business`)
- build a single exe to ease install on windows (following http://milkator.wordpress.com/2014/07/19/windows-executable-from-python-developing-in-ubuntu/)

Indices and tables
==================

   * :ref:`genindex`
   * :ref:`modindex`
   * :ref:`search`
